summaryrefslogtreecommitdiffstats
path: root/kresources/groupwise/soap/ksslsocket.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/groupwise/soap/ksslsocket.cpp')
-rw-r--r--kresources/groupwise/soap/ksslsocket.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kresources/groupwise/soap/ksslsocket.cpp b/kresources/groupwise/soap/ksslsocket.cpp
index e1e48831..eef6a5bf 100644
--- a/kresources/groupwise/soap/ksslsocket.cpp
+++ b/kresources/groupwise/soap/ksslsocket.cpp
@@ -109,7 +109,7 @@ void KSSLSocket::slotConnected()
d->kssl->reInitialize();
}
d->kssl->setPeerHost(host());
-// kdDebug() << "SOCKET STATUS: " << sockeStatus() << endl;
+// kdDebug() << "SOCKET STATUS: " << socketqStatus() << endl;
int rc = d->kssl->connect( sockfd );
if ( rc <= 0 ) {
kdError() << "Error connecting KSSL: " << rc << endl;
@@ -157,7 +157,7 @@ TQString KSSLSocket::metaData( const TQString &key )
{
if( d->metaData.tqcontains(key) )
return d->metaData[key];
- return TQString::null;
+ return TQString();
}
/*
@@ -279,9 +279,9 @@ int KSSLSocket::verifyCertificate()
setMetaData("ssl_action", "accept");
}
- // Since we're the parent, we need to teach the child.
- setMetaData("ssl_parent_ip", ourIp );
- setMetaData("ssl_parent_cert", pc.toString());
+ // Since we're the tqparent, we need to teach the child.
+ setMetaData("ssl_tqparent_ip", ourIp );
+ setMetaData("ssl_tqparent_cert", pc.toString());
// - Read from cache and see if there is a policy for this
KSSLCertificateCache::KSSLCertificatePolicy cp = d->cc->getPolicyByCertificate(pc);